@@ -11,6 +11,7 @@ import unittest, time, logging, os, inspect
 from ..utils.general.Base_Logging import Base_Logging
 from ..remoteTest.BrowserStack_Library import BrowserStack_Library
 from ..drivers.driverfactory import DriverFactory
+from jinja2 import Template
 # from utils.Test_Rail import Test_Rail
 # from utils import Tesults
 from ..utils.general.stop_test_exception_util import Stop_Test_Exception
@@ -392,6 +393,21 @@ class Base_Page(Borg, unittest.TestCase):
             self.append_latest_image(screenshot_name)
         if self.tesults_flag is True:
             self.images.append(screenshot_name)
+            # Add screenshot to HTML report using Jinja2
+            with open('report.html', 'w') as file:
+                template = Template('''
+                        <html>
+                        <head>
+                            <title>Test Report</title>
+                        </head>
+                        <body>
+                            {% for image in images %}
+                            <img src="{{ image }}" alt="screenshot">
+                            {% endfor %}
+                        </body>
+                        </html>
+                        ''')
+                file.write(template.render(images=self.images))
 
     def open(self, url, wait_time=2):
         "Visit the page base_url + url"
